<?php

namespace Drupal\wbm2cm\Commands;

use Drupal\Core\Extension\ModuleInstallerInterface;
use Drupal\wbm2cm\MigrationController;
use Drush\Commands\DrushCommands;

class Wbm2cmCommands extends DrushCommands {

  protected $controller;

  protected $moduleInstaller;

  public function __construct(MigrationController $controller, ModuleInstallerInterface $module_installer) {
    $this->controller = $controller;
    $this->moduleInstaller = $module_installer;
  }

  /**
   * @command wbm2cm:migrate
   * @aliases wbm2cm-migrate
   */
  public function migrate() {
    $out = $this->output();

    $out->writeln('Saving existing moderation states to temporary tables...');
    $messages = $this->controller->executeStepWithMessages('save');
    array_walk($messages, [$out, 'writeln']);

    $out->writeln('Removing Workbench Moderation data...');
    $messages = $this->controller->executeStepWithMessages('clear');
    array_walk($messages, [$out, 'writeln']);

    $out->writeln('Installing Content Moderation...');
    $this->moduleInstaller->uninstall(['workbench_moderation']);
    $this->moduleInstaller->install(['content_moderation']);

    $out->writeln('Restoring moderation states from temporary tables...');
    $messages = $this->controller->executeStepWithMessages('restore');
    array_walk($messages, [$out, 'writeln']);

    $out->writeln('Yay! You have been migrated to Content Moderation.');
  }

}
